@@ -6,7 +6,7 @@ use Carp;
 use Argon::Client;
 
 use parent qw(Exporter);
-our @EXPORT = qw(connect process task);
+our @EXPORT = qw(connect process);
 
 my $CLIENT;
 
@@ -28,14 +28,10 @@ sub connect {
 }
 
 sub process (&@) {
-    goto \&task;
-}
-
-sub task ($@) {
-    my ($task_class, @args) = @_;
+    my ($f, $args) = @_;
     croak 'not connected' unless $CLIENT;
 
-    my $msgid    = $CLIENT->queue($task_class, \@args);
+    my $msgid    = $CLIENT->queue($f, $args);
     my $deferred = sub { $CLIENT->collect($msgid) };
 
     return $deferred unless wantarray;
@@ -98,15 +94,6 @@ system and is available.
 When called in list context, additionally returns a CODE reference which
 evaluates to true when the task has been completed by the Argon system.
 
-See also L<Coro::ProcessPool/A NOTE ABOUT IMPORTS AND CLOSURES>, which has
-some important information about C<use> and C<require>.
-
-=head2 task 'Task::Class', @args
-
-Similar to process, but passes in the name of a class implementing the methods
-C<new(@args)> and C<run>. The result of C<run> is returned. Note that the class
-must be found on the workers' include paths.
-
 =head1 AUTHOR
 
 Jeff Ober <jeffober@gmail.com>
